@@ -81,19 +81,21 @@ extern int yydebug;
     STATEMENT_SEPERATOR = 287,
     CAPITAL_STRING = 288,
     DO_COUNT = 289,
-    MAKE_UNIQUE = 290,
-    NE = 291,
-    EQ = 292,
-    GT = 293,
-    LT = 294,
-    LE = 295,
-    GE = 296,
-    RANGE = 297,
-    FN_MAX = 298,
-    FN_MIN = 299,
-    FN_ABS = 300,
-    FN_POOL = 301,
-    UMINUS = 302
+    UNIQUE = 290,
+    IS_EVEN = 291,
+    IS_ODD = 292,
+    RANGE = 293,
+    FN_MAX = 294,
+    FN_MIN = 295,
+    FN_ABS = 296,
+    FN_POOL = 297,
+    UMINUS = 298,
+    NE = 299,
+    EQ = 300,
+    GT = 301,
+    LT = 302,
+    LE = 303,
+    GE = 304
   };
 #endif
 /* Tokens.  */
@@ -129,29 +131,31 @@ extern int yydebug;
 #define STATEMENT_SEPERATOR 287
 #define CAPITAL_STRING 288
 #define DO_COUNT 289
-#define MAKE_UNIQUE 290
-#define NE 291
-#define EQ 292
-#define GT 293
-#define LT 294
-#define LE 295
-#define GE 296
-#define RANGE 297
-#define FN_MAX 298
-#define FN_MIN 299
-#define FN_ABS 300
-#define FN_POOL 301
-#define UMINUS 302
+#define UNIQUE 290
+#define IS_EVEN 291
+#define IS_ODD 292
+#define RANGE 293
+#define FN_MAX 294
+#define FN_MIN 295
+#define FN_ABS 296
+#define FN_POOL 297
+#define UMINUS 298
+#define NE 299
+#define EQ 300
+#define GT 301
+#define LT 302
+#define LE 303
+#define GE 304
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 100 "src/grammar/dice.yacc"
+#line 103 "src/grammar/dice.yacc"
 
     vec values;
 
-#line 155 "y.tab.h"
+#line 159 "y.tab.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
