@@ -12,10 +12,13 @@ typedef enum {
   GREATER_OR_EQUALS = 4,
   LESS_OR_EQUALS = 5,
   NOT_EQUAL = 6,
-  UNIQUE = 7
+  IS_UNIQUE = 7,
+  IF_EVEN = 8,
+  IF_ODD = 9,
 } COMPARATOR;
 
 int check_condition(vec* x, vec* y, COMPARATOR c);
 
 int check_condition_scalar(int x, int y, COMPARATOR c);
+int check_condition_vector(vec* v, COMPARATOR c);
 #endif
